Zimbra Python Client (pyzimbra)
===============================

fork of https://github.com/ilgarm/pyzimbra/


About
-----

This library aimed to help those who want to talk to zimbra instance from
python.


Features
--------

What is possible at the moment:

* authentication to zimbra using account name and password
* pre-authentication to zimbra using domain key
* administrative login to zimbra
* execute any method via soap by preparing xml request
* get back proper exception message and code from zimbra
* use library behind proxy

What is missing and coming in the future:

* zimbra client api: set of python classes to use instead of dealing with xml
  directly


Contributors
------------

* Ilgar Mashayev, Original Author
* Vitaliy Podoba


Contacts
--------

report bugs at: https://github.com/vnc-biz/pyzimbra/issues

